@@ -1,7 +1,6 @@
 /*============================================================================
-
-  WCSLIB 5.19 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2018, Mark Calabretta
+  WCSLIB 7.6 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2021, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -18,14 +17,12 @@
   You should have received a copy of the GNU Lesser General Public License
   along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
-
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: spc.h,v 5.19 2018/07/26 15:37:04 mcalabre Exp $
+  $Id: spc.h,v 7.6 2021/04/13 12:57:01 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 5.19 - C routines that implement the FITS World Coordinate System
+* WCSLIB 7.6 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -52,7 +49,8 @@
 *
 * Routine spcini() is provided to initialize the spcprm struct with default
 * values, spcfree() reclaims any memory that may have been allocated to store
-* an error message, and spcprt() prints its contents.
+* an error message, spcsize() computes its total size including allocated
+* memory, and spcprt() prints its contents.
 *
 * spcperr() prints the error message(s) (if any) stored in a spcprm struct.
 *
@@ -183,6 +181,11 @@
 * spcini() sets all members of a spcprm struct to default values.  It should
 * be used to initialize every spcprm struct.
 *
+* PLEASE NOTE: If the spcprm struct has already been initialized, then before
+* reinitializing, it spcfree() should be used to free any memory that may have
+* been allocated to store an error message.  A memory leak may otherwise
+* result.
+*
 * Given and returned:
 *   spc       struct spcprm*
 *                       Spectral transformation parameters.
@@ -208,6 +211,33 @@
 *                         1: Null spcprm pointer passed.
 *
 *
+* spcsize() - Compute the size of a spcprm struct
+* -----------------------------------------------
+* spcsize() computes the full size of a spcprm struct, including allocated
+* memory.
+*
+* Given:
+*   spc       const struct spcprm*
+*                       Spectral transformation parameters.
+*
+*                       If NULL, the base size of the struct and the allocated
+*                       size are both set to zero.
+*
+* Returned:
+*   sizes     int[2]    The first element is the base size of the struct as
+*                       returned by sizeof(struct spcprm).  The second element
+*                       is the total allocated size, in bytes.  This figure
+*                       includes memory allocated for the constituent struct,
+*                       spcprm::err.
+*
+*                       It is not an error for the struct not to have been set
+*                       up via spcset().
+*
+* Function return value:
+*             int       Status return value:
+*                         0: Success.
+*
+*
 * spcprt() - Print routine for the spcprm struct
 * ----------------------------------------------
 * spcprt() prints the contents of a spcprm struct using wcsprintf().  Mainly
@@ -789,67 +819,67 @@ extern "C" {
 extern const char *spc_errmsg[];
 
 enum spc_errmsg_enum {
-  SPCERR_NO_CHANGE       = -1,	/* No change. */
-  SPCERR_SUCCESS         =  0,	/* Success. */
-  SPCERR_NULL_POINTER    =  1,	/* Null spcprm pointer passed. */
-  SPCERR_BAD_SPEC_PARAMS =  2,	/* Invalid spectral parameters. */
-  SPCERR_BAD_X           =  3,	/* One or more of x coordinates were
-				   invalid. */
-  SPCERR_BAD_SPEC        =  4 	/* One or more of the spec coordinates were
-				   invalid. */
+  SPCERR_NO_CHANGE       = -1,	// No change.
+  SPCERR_SUCCESS         =  0,	// Success.
+  SPCERR_NULL_POINTER    =  1,	// Null spcprm pointer passed.
+  SPCERR_BAD_SPEC_PARAMS =  2,	// Invalid spectral parameters.
+  SPCERR_BAD_X           =  3,	// One or more of x coordinates were
+				// invalid.
+  SPCERR_BAD_SPEC        =  4 	// One or more of the spec coordinates were
+				// invalid.
 };
 
 struct spcprm {
-  /* Initialization flag (see the prologue above).                          */
-  /*------------------------------------------------------------------------*/
-  int    flag;			/* Set to zero to force initialization.     */
+  // Initialization flag (see the prologue above).
+  //--------------------------------------------------------------------------
+  int    flag;			// Set to zero to force initialization.
 
-  /* Parameters to be provided (see the prologue above).                    */
-  /*------------------------------------------------------------------------*/
-  char   type[8];		/* Four-letter spectral variable type.      */
-  char   code[4];		/* Three-letter spectral algorithm code.    */
+  // Parameters to be provided (see the prologue above).
+  //--------------------------------------------------------------------------
+  char   type[8];		// Four-letter spectral variable type.
+  char   code[4];		// Three-letter spectral algorithm code.
 
-  double crval;			/* Reference value (CRVALia), SI units.     */
-  double restfrq;		/* Rest frequency, Hz.                      */
-  double restwav;		/* Rest wavelength, m.                      */
+  double crval;			// Reference value (CRVALia), SI units.
+  double restfrq;		// Rest frequency, Hz.
+  double restwav;		// Rest wavelength, m.
 
-  double pv[7];			/* Grism parameters:                        */
-				/*   0: G, grating ruling density.          */
-				/*   1: m, interference order.              */
-				/*   2: alpha, angle of incidence.          */
-				/*   3: n_r, refractive index at lambda_r.  */
-				/*   4: n'_r, dn/dlambda at lambda_r.       */
-				/*   5: epsilon, grating tilt angle.        */
-				/*   6: theta, detector tilt angle.         */
+  double pv[7];			// Grism parameters:
+				//   0: G, grating ruling density.
+				//   1: m, interference order.
+				//   2: alpha, angle of incidence.
+				//   3: n_r, refractive index at lambda_r.
+				//   4: n'_r, dn/dlambda at lambda_r.
+				//   5: epsilon, grating tilt angle.
+				//   6: theta, detector tilt angle.
 
-  /* Information derived from the parameters supplied.                      */
-  /*------------------------------------------------------------------------*/
-  double w[6];			/* Intermediate values.                     */
-				/*   0: Rest frequency or wavelength (SI).  */
-				/*   1: CRVALX (SI units).                  */
-				/*   2: CDELTX/CDELTia = dX/dS (SI units).  */
-				/* The remainder are grism intermediates.   */
+  // Information derived from the parameters supplied.
+  //--------------------------------------------------------------------------
+  double w[6];			// Intermediate values.
+				//   0: Rest frequency or wavelength (SI).
+				//   1: CRVALX (SI units).
+				//   2: CDELTX/CDELTia = dX/dS (SI units).
+				// The remainder are grism intermediates.
 
-  int    isGrism;		/* Grism coordinates?  1: vacuum, 2: air.   */
-  int    padding1;		/* (Dummy inserted for alignment purposes.) */
+  int    isGrism;		// Grism coordinates?  1: vacuum, 2: air.
+  int    padding1;		// (Dummy inserted for alignment purposes.)
 
-  /* Error handling                                                         */
-  /*------------------------------------------------------------------------*/
+  // Error handling
+  //--------------------------------------------------------------------------
   struct wcserr *err;
 
-  /* Private                                                                */
-  /*------------------------------------------------------------------------*/
-  void   *padding2;		/* (Dummy inserted for alignment purposes.) */
-  int (*spxX2P)(SPX_ARGS);	/* Pointers to the transformation functions */
-  int (*spxP2S)(SPX_ARGS);	/* in the two-step algorithm chain in the   */
-				/* pixel-to-spectral direction.             */
+  // Private
+  //--------------------------------------------------------------------------
+  void   *padding2;		// (Dummy inserted for alignment purposes.)
+  int (*spxX2P)(SPX_ARGS);	// Pointers to the transformation functions
+  int (*spxP2S)(SPX_ARGS);	// in the two-step algorithm chain in the
+				// pixel-to-spectral direction.
 
-  int (*spxS2P)(SPX_ARGS);	/* Pointers to the transformation functions */
-  int (*spxP2X)(SPX_ARGS);	/* in the two-step algorithm chain in the   */
-				/* spectral-to-pixel direction.             */
+  int (*spxS2P)(SPX_ARGS);	// Pointers to the transformation functions
+  int (*spxP2X)(SPX_ARGS);	// in the two-step algorithm chain in the
+				// spectral-to-pixel direction.
 };
 
-/* Size of the spcprm struct in int units, used by the Fortran wrappers. */
+// Size of the spcprm struct in int units, used by the Fortran wrappers.
 #define SPCLEN (sizeof(struct spcprm)/sizeof(int))
 
 
@@ -857,6 +887,8 @@ int spcini(struct spcprm *spc);
 
 int spcfree(struct spcprm *spc);
 
+int spcsize(const struct spcprm *spc, int sizes[2]);
+
 int spcprt(const struct spcprm *spc);
 
 int spcperr(const struct spcprm *spc, const char *prefix);
@@ -888,7 +920,7 @@ int spctrne(const char ctypeS1[9], double crvalS1, double cdeltS1,
 int spcaips(const char ctypeA[9], int velref, char ctype[9], char specsys[9]);
 
 
-/* Deprecated. */
+// Deprecated.
 #define spcini_errmsg spc_errmsg
 #define spcprt_errmsg spc_errmsg
 #define spcset_errmsg spc_errmsg
@@ -911,4 +943,4 @@ int spctrn(const char ctypeS1[9], double crvalS1, double cdeltS1,
 }
 #endif
 
-#endif /* WCSLIB_SPC */
+#endif // WCSLIB_SPC
