@@ -1,5 +1,5 @@
 /*============================================================================
-  WCSLIB 7.5 - an implementation of the FITS WCS standard.
+  WCSLIB 7.6 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2021, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -19,10 +19,10 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcsfix.h,v 7.5 2021/03/20 05:54:58 mcalabre Exp $
+  $Id: wcsfix.h,v 7.6 2021/04/13 12:57:01 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 7.5 - C routines that implement the FITS World Coordinate System
+* WCSLIB 7.6 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -54,6 +54,13 @@
 * consistency of pairs of keyvalues that define the same measure in two
 * different ways, for example, as a date and an MJD.
 *
+* A separate routine, wcspcx(), "regularizes" the linear transformation matrix
+* component (PCi_j) of the coordinate transformation to make it more human-
+* readable.  Where a coordinate description was constructed from CDi_j, it
+* decomposes it into PCi_j + CDELTi in a meaningful way.  Optionally, it can
+* also diagonalize the PCi_j matrix (as far as possible), i.e. undo the
+* transposition of axes in the intermediate pixel coordinate system.
+*
 * Non-standard keyvalues:
 * -----------------------
 *   AIPS-convention celestial projection types, NCP and GLS, and spectral
@@ -174,6 +181,9 @@
 * not given default to zero.  This results in a singular matrix with an
 * intersecting row and column of zeros.
 *
+* cdfix() is expected to be invoked before wcsset(), which will fail if these
+* errors have not been corrected.
+*
 * Given and returned:
 *   wcs       struct wcsprm*
 *                       Coordinate transformation parameters.
@@ -201,6 +211,9 @@
 * are set but disagree with dateobs or mjdobs by more than 0.000002 year
 * (63.2 seconds), an informative message is produced.
 *
+* The translations done by datfix() do not affect and are not affected by
+* wcsset().
+*
 * Given and returned:
 *   wcs       struct wcsprm*
 *                       Coordinate transformation parameters.
@@ -236,6 +249,9 @@
 * it.  If both triplets are set, then it checks for consistency at the level
 * of 1 metre.
 *
+* The operations done by obsfix() do not affect and are not affected by
+* wcsset().
+*
 * Given:
 *   ctrl      int       Flag that controls behaviour if one triplet is
 *                       defined and the other is only partially defined:
@@ -317,6 +333,9 @@
 * unitfix() applies wcsutrn() to translate non-standard CUNITia keyvalues,
 * e.g. 'DEG' -> 'deg', also stripping off unnecessary whitespace.
 *
+* unitfix() is expected to be invoked before wcsset(), which will fail if
+* non-standard CUNITia keyvalues have not been translated.
+*
 * Given:
 *   ctrl      int       Do potentially unsafe translations described in the
 *                       usage notes to wcsutrn().
@@ -345,6 +364,16 @@
 *
 * Note that if wcs::specsys is already set then it will not be overridden.
 *
+* AIPS-convention spectral types set in CTYPEia are translated on-the-fly by
+* wcsset() but without modifying wcsprm::ctype[] or wcsprm::specsys.  That is,
+* only the information extracted from wcsprm::ctype[] is translated when
+* wcsset() fills in wcsprm::spc (spcprm struct).  spcfix() modifies
+* wcsprm::ctype[] so that if the header is subsequently written out, e.g. by
+* wcshdo(), then it will contain translated CTYPEia keyvalues.
+*
+* The operations done by spcfix() do not affect and are not affected by
+* wcsset().
+*
 * Given and returned:
 *   wcs       struct wcsprm*
 *                       Coordinate transformation parameters.  wcsprm::ctype[]
@@ -381,6 +410,18 @@
 * necessary.  Otherwise, error 2 will be returned if sufficient empty slots
 * are not already available for use.
 *
+* AIPS-convention celestial projection types set in CTYPEia are translated
+* on-the-fly by wcsset() but without modifying wcsprm::ctype[], wcsprm::pv[],
+* or wcsprm::npv.  That is, only the information extracted from
+* wcsprm::ctype[] is translated when wcsset() fills in wcsprm::cel (celprm
+* struct).  celfix() modifies wcsprm::ctype[], wcsprm::pv[], and wcsprm::npv
+* so that if the header is subsequently written out, e.g. by wcshdo(), then it
+* will contain translated CTYPEia keyvalues and the relevant PVi_ma.
+*
+* The operations done by celfix() do not affect and are not affected by
+* wcsset().  However, it uses information in the wcsprm struct provided by
+* wcsset(), and will invoke it if necessary.
+*
 * Given and returned:
 *   wcs       struct wcsprm*
 *                       Coordinate transformation parameters.  wcsprm::ctype[]
@@ -409,6 +450,10 @@
 * cylfix() fixes WCS keyvalues for malformed cylindrical projections that
 * suffer from the problem described in Sect. 7.3.4 of Paper I.
 *
+* cylfix() requires the wcsprm struct to have been set up by wcsset(), and
+* will invoke it if necessary.  After modification, the struct is reset on
+* return with an explicit call to wcsset().
+*
 * Given:
 *   naxis     const int []
 *                       Image axis lengths.
@@ -438,6 +483,98 @@
 *                       wcsprm::err if enabled, see wcserr_enable().
 *
 *
+* wcspcx() - regularize PCi_j
+* ---------------------------
+* wcspcx() "regularizes" the linear transformation matrix component of the
+* coordinate transformation (PCi_ja) to make it more human-readable.
+*
+* Normally, upon encountering a FITS header containing a CDi_ja matrix,
+* wcsset() simply treats it as PCi_ja and sets CDELTia to unity.  However,
+* wcspcx() decomposes CDi_ja into PCi_ja and CDELTia in such a way that
+* CDELTia form meaningful scaling parameters.  In practice, the residual
+* PCi_ja matrix will often then be orthogonal, i.e. unity, or describing a
+* pure rotation, axis permutation, or reflection, or a combination thereof.
+*
+* The decomposition is based on normalizing the length in the transformed
+* system (i.e. intermediate pixel coordinates) of the orthonormal basis
+* vectors of the pixel coordinate system.  This deviates slightly from the
+* prescription given by Eq. (4) of WCS Paper I, namely Sum(j=1,N)(PCi_ja)² = 1,
+* in replacing the sum over j with the sum over i.  Consequently, the columns
+* of PCi_ja will consist of unit vectors.  In practice, especially in cubes
+* and higher dimensional images, at least some pairs of these unit vectors, if
+* not all, will often be orthogonal or close to orthogonal.
+*
+* The sign of CDELTia is chosen to make the PCi_ja matrix as close to the,
+* possibly permuted, unit matrix as possible, except that where the coordinate
+* description contains a pair of celestial axes, the sign of CDELTia is set
+* negative for the longitude axis and positive for the latitude axis.
+*
+* Optionally, rows of the PCi_ja matrix may also be permuted to diagonalize
+* it as far as possible, thus undoing any transposition of axes in the
+* intermdiate pixel coordinate system.
+*
+* If the coordinate description contains a celestial plane, then the angle of
+* rotation of each of the basis vectors associated with the celestial axes is
+* returned.  For a pure rotation the two angles should be identical.  Any
+* difference between them is a measure of axis skewness.
+*
+* The decomposition is not performed for axes involving a sequent distortion
+* function that is defined in terms of CDi_ja, such as TPV, TNX, or ZPX, which
+* always are.  The independent variables of the polynomial are therefore
+* intermediate world coordinates rather than intermediate pixel coordinates.
+* Because sequent distortions are always applied before CDELTia, if CDi_ja was
+* translated to PCi_ja plus CDELTia, then the distortion would be altered
+* unless the polynomial coefficients were also adjusted to account for the
+* change of scale.
+*
+* wcspcx() requires the wcsprm struct to have been set up by wcsset(), and
+* will invoke it if necessary.  The wcsprm struct is reset on return with an
+* explicit call to wcsset().
+*
+* Given and returned:
+*   wcs       struct wcsprm*
+*                       Coordinate transformation parameters.
+*
+* Given:
+*   dopc      int       If 1, then PCi_ja and CDELTia, as given, will be
+*                       recomposed according to the above prescription.  If 0,
+*                       the operation is restricted to decomposing CDi_ja.
+*
+*   permute   int       If 1, then after decomposition (or recomposition),
+*                       permute rows of PCi_ja to make the axes of the
+*                       intermediate pixel coordinate system match as closely
+*                       as possible those of the pixel coordinates.  That is,
+*                       make it as close to a diagonal matrix as possible.
+*                       However, celestial axes are special in always being
+*                       paired, with the longitude axis preceding the latitude
+*                       axis.
+*
+*                       All WCS entities indexed by i, such as CTYPEia,
+*                       CRVALia, CDELTia, etc., including coordinate lookup
+*                       tables, will also be permuted as necessary to account
+*                       for the change to PCi_ja.  This does not apply to
+*                       CRPIXja, nor prior distortion functions.  These
+*                       operate on pixel coordinates, which are not affected
+*                       by the permutation.
+*
+* Returned:
+*   rotn      double[2] Rotation angle [deg] of each basis vector associated
+*                       with the celestial axes.  For a pure rotation the two
+*                       angles should be identical.  Any difference between
+*                       them is a measure of axis skewness.
+*
+*                       May be set to the NULL pointer if this information is
+*                       not required.
+*
+* Function return value:
+*             int       Status return value:
+*                         0: Success.
+*                         1: Null wcsprm pointer passed.
+*                         2: Memory allocation failed.
+*                         5: CDi_j matrix not used.
+*                         6: Sequent distortion function present.
+*
+*
 * Global variable: const char *wcsfix_errmsg[] - Status return messages
 * ---------------------------------------------------------------------
 * Error messages to match the status value returned from each function.
@@ -509,6 +646,8 @@ int celfix(struct wcsprm *wcs);
 
 int cylfix(const int naxis[], struct wcsprm *wcs);
 
+int wcspcx(struct wcsprm *wcs, int dopc, int permute, double rotn[2]);
+
 
 #ifdef __cplusplus
 }
